pub trait StaticAtomSet: Ord {
// Required method
fn get() -> &'static PhfStrSet;
}Expand description
A static PhfStrSet
This trait is implemented by static sets of interned strings generated using
string_cache_codegen, and EmptyStaticAtomSet for when strings will be added dynamically.
It is used by the methods of Atom to check if a string is present in the static set.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.